Actions, Resources, and Condition Keys for Amazon Route53 Domains - AWS Identity and Access Management
Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon Route53 Domains.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

AWS Identity and Access Management
User Guide

The AWS Documentation website is getting a new look!
Try it now and let us know what you think. Switch to the new look >>
You can return to the original look by selecting English in the language selector above.

# Actions, Resources, and Condition Keys for Amazon Route53 Domains

Amazon Route53 Domains (service prefix: `route53domains`) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service.

- View a list of the API operations available for this service.

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by Amazon Route53 Domains
- Resources Defined by Amazon Route53 Domains
- Condition Keys for Amazon Route53 Domains

## Actions Defined by Amazon Route53 Domains

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table.

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
CheckDomainAvailability | Grants permission to check the availability of one domain name | Read |  |  |
DeleteTagsForDomain | Grants permission to delete the specified tags for a domain | Tagging |  |  |
DisableDomainAutoRenew | Grants permission to configure Amazon Route 53 to automatically renew the specified domain before the domain registration expires | Write |  |  |
DisableDomainTransferLock | Grants permission to remove the transfer lock on the domain (specifically the clientTransferProhibited status) to allow domain transfers | Write |  |  |
EnableDomainAutoRenew | Grants permission to configure Amazon Route 53 to automatically renew the specified domain before the domain registration expires | Write |  |  |
EnableDomainTransferLock | Grants permission to set the transfer lock on the domain (specifically the clientTransferProhibited status) to prevent domain transfers | Write |  |  |
GetContactReachabilityStatus | For operations that require confirmation that the email address for the registrant contact is valid, such as registering a new domain, grants permission to get information about whether the registrant contact has responded | Read |  |  |
GetDomainDetail | Grants permission to get detailed information about a domain | Read |  |  |
GetDomainSuggestions | Grants permission to get a list of suggested domain names given a string, which can either be a domain name or simply a word or phrase (without spaces) | Read |  |  |
GetOperationDetail | Grants permission to get the current status of an operation that is not completed | Read |  |  |
ListDomains | Grants permission to list all the domain names registered with Amazon Route 53 for the current AWS account | List |  |  |
ListOperations | Grants permission to list the operation IDs of operations that are not yet complete | List |  |  |
ListTagsForDomain | Grants permission to list all the tags that are associated with the specified domain | List |  |  |
RegisterDomain | Grants permission to register domains | Write |  |  |
RenewDomain | Grants permission to renew domains for the specified number of years | Write |  |  |
ResendContactReachabilityEmail | For operations that require confirmation that the email address for the registrant contact is valid, such as registering a new domain, grants permission to resend the confirmation email to the current email address for the registrant contact | Write |  |  |
RetrieveDomainAuthCode | Grants permission to get the AuthCode for the domain | Write |  |  |
TransferDomain | Grants permission to transfer a domain from another registrar to Amazon Route 53 | Write |  |  |
UpdateDomainContact | Grants permission to update the contact information for domain | Write |  |  |
UpdateDomainContactPrivacy | Grants permission to update the domain contact privacy setting | Write |  |  |
UpdateDomainNameservers | Grants permission to replace the current set of name servers for a domain with the specified set of name servers | Write |  |  |
UpdateTagsForDomain | Grants permission to add or update tags for a specified domain | Tagging |  |  |
ViewBilling | Grants permission to get all the domain-related billing records for the current AWS account for a specified period | Read |  |  |

## Resources Defined by Amazon Route53 Domains

Amazon Route53 Domains does not support specifying a resource ARN in the `Resource` element of an IAM policy statement. To allow access to Amazon Route53 Domains, specify `“Resource”: “*”` in your policy.

## Condition Keys for Amazon Route53 Domains

Route53 Domains has no service-specific context keys that can be used in the `Condition` element of policy statements. For the list of the global context keys that are available to all services, see Available Keys for Conditions in the IAM Policy Reference.

On this page:

- Actions Defined by Amazon Route53 Domains
- Resources Defined by Amazon Route53 Domains
- Condition Keys for Amazon Route53 Domains

We use cookies to provide and improve our services. By using our site, you consent to cookies. Learn more